@@ -1,9 +1,11 @@
-from .motors import Motor, MotorPair
+from .motors import Motor, MotorPair, PassiveMotor
 from .distance import DistanceSensor
 from .force import ForceSensor
 from .color import ColorSensor
 from .colordistance import ColorDistanceSensor
 from .matrix import Matrix
+from .wedo import TiltSensor, MotionSensor
+from .light import Light
 from .hat import Hat
 from .serinterface import BuildHAT
 from .exc import *
